@@ -93,6 +93,22 @@ class Reddio(object):
         except Exception as e:
             raise e
 
+    def get_collection(self, contract_address, token_ids):
+        uri = '/v1/collection' + '?quote_contract_address=' + str(contract_address)
+        if isinstance(token_ids, list):
+            token_ids = ','.join(str(i) for i in token_ids)
+            uri += '&token_ids=' + str(token_ids)
+        url = self.endpoint + uri
+        headers = {'Content-Type': 'application/json'}
+        r = requests.get(url, headers = headers)
+        order_list = []
+        try:
+            return r.json()["data"]["list"]
+        except (TypeError, KeyError):
+            return r.json()['error']
+        except Exception as e:
+            raise e
+
     def list_nft_by_user(self, stark_key, contract_address):
         uri = '/v1/balances' + '?stark_key=' + str(stark_key) + '&contract_address=' + str(contract_address) + '&limit=1000'
         url = self.endpoint + uri
@@ -236,6 +252,7 @@ class Reddio(object):
             return r.json()['error']
         except Exception as e:
             raise e
+            
     def withdrawNFT(self, stark_private_key, sender_starkkey, receiver, token_type, contract, tokenID, expiration_timestamp=4194303):
         quantum = 1
         asset_id =  hex(get_asset_id(token_type, contract, quantum, int(tokenID)))
